@@ -2,7 +2,7 @@
 #
 # Author: Yipeng Sun
 # License: BSD 2-clause
-# Last Change: Sun May 16, 2021 at 12:44 AM +0200
+# Last Change: Tue May 18, 2021 at 04:09 AM +0200
 
 import numpy as np
 import matplotlib as mp
@@ -83,6 +83,14 @@ def ax_add_args_errorbar(label, color, yerr=None, marker='o'):
     }
 
 
+def ax_add_args_step(label, color, where='mid'):
+    return {
+        'label': label,
+        'color': color,
+        'where': where
+    }
+
+
 def ax_add_args_default(num, mean, std, *args, **kwargs):
     return ax_add_args_simple(
         'tot: {:.4g} mean {:.2g} std: {:.2g}'.format(
@@ -220,22 +228,6 @@ def plot_histo(histo, bins, histo_add_args,
     return output, fig, ax
 
 
-@decorate_output
-def plot_two_histos(histo1, bins1, histo2, bins2,
-                    histo1_add_args, histo2_add_args,
-                    output=None,
-                    **kwargs):
-    kw_plot_prepare, kw_rest = filter_kwargs_plot_prepare(kwargs)
-    fig, ax = plot_prepare(**kw_plot_prepare)
-
-    _, ax1 = plot_histo(histo1, bins1, histo1_add_args, figure=fig, axis=ax,
-                        show_legend=False, **kw_rest)
-    _, ax2 = plot_histo(histo2, bins2, histo2_add_args, figure=fig, axis=ax1,
-                        **kw_rest)
-
-    return output, fig, ax1, ax2
-
-
 @decorate_output
 def plot_errorbar(x, y, errorbar_add_args,
                   output=None,
@@ -262,6 +254,52 @@ def plot_errorbar(x, y, errorbar_add_args,
     return output, fig, ax
 
 
+@decorate_output
+def plot_step(x, y, step_add_args,
+              output=None,
+              convert_x=True,
+              show_legend=True, legend_loc='best',
+              xlim=None, ylim=None,
+              **kwargs):
+    fig, ax = plot_prepare(**kwargs)
+
+    if convert_x:
+        x = convert_bins_to_central_pos(x)
+
+    ax.step(x, y, **step_add_args)
+
+    if show_legend:
+        ax.legend(numpoints=1, loc=legend_loc)
+
+    if xlim:
+        ax.set_xlim(xlim)
+
+    if ylim:
+        ax.set_ylim(ylim)
+
+    return output, fig, ax
+
+
+##########################
+# Common composite plots #
+##########################
+
+@decorate_output
+def plot_two_histos(histo1, bins1, histo2, bins2,
+                    histo1_add_args, histo2_add_args,
+                    output=None,
+                    **kwargs):
+    kw_plot_prepare, kw_rest = filter_kwargs_plot_prepare(kwargs)
+    fig, ax = plot_prepare(**kw_plot_prepare)
+
+    _, ax1 = plot_histo(histo1, bins1, histo1_add_args, figure=fig, axis=ax,
+                        show_legend=False, **kw_rest)
+    _, ax2 = plot_histo(histo2, bins2, histo2_add_args, figure=fig, axis=ax1,
+                        **kw_rest)
+
+    return output, fig, ax1, ax2
+
+
 @decorate_output
 def plot_two_errorbar(x1, y1, x2, y2, errorbar1_add_args, errorbar2_add_args,
                       output=None,
